@@ -33,10 +33,8 @@ import frozendict  # noqa: F401
 from snaptrade_client import schemas  # noqa: F401
 
 from snaptrade_client.model.exchange_rate_pairs import ExchangeRatePairs as ExchangeRatePairsSchema
-from snaptrade_client.model.currency import Currency as CurrencySchema
 
 from snaptrade_client.type.exchange_rate_pairs import ExchangeRatePairs
-from snaptrade_client.type.currency import Currency
 
 from . import path
 
@@ -110,16 +108,17 @@ class BaseApi(api_client.Api):
     async def _alist_all_currencies_rates_oapg(
         self,
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
         AsyncGeneratorResponse,
     ]:
         """
-        List currency exchange rates
+        Get currency exchange rates
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -136,6 +135,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/currencies/rates',
             auth_settings=_auth,
             headers=_headers,
         )
@@ -146,6 +146,7 @@ class BaseApi(api_client.Api):
             headers=_headers,
             auth_settings=_auth,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -205,7 +206,7 @@ class BaseApi(api_client.Api):
     def _list_all_currencies_rates_oapg(
         self,
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
     ) -> typing.Union[
@@ -213,7 +214,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        List currency exchange rates
+        Get currency exchange rates
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -230,6 +231,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/currencies/rates',
             auth_settings=_auth,
             headers=_headers,
         )
@@ -271,6 +273,7 @@ class ListAllCurrenciesRates(BaseApi):
 
     async def alist_all_currencies_rates(
         self,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -279,6 +282,7 @@ class ListAllCurrenciesRates(BaseApi):
         args = self._list_all_currencies_rates_mapped_args(
         )
         return await self._alist_all_currencies_rates_oapg(
+            **kwargs,
         )
     
     def list_all_currencies_rates(
@@ -297,6 +301,7 @@ class ApiForget(BaseApi):
 
     async def aget(
         self,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -305,6 +310,7 @@ class ApiForget(BaseApi):
         args = self._list_all_currencies_rates_mapped_args(
         )
         return await self._alist_all_currencies_rates_oapg(
+            **kwargs,
         )
     
     def get(
