@@ -13,10 +13,11 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.account_order_record import AccountOrderRecord
 from snaptrade_client.type.balance import Balance
+from snaptrade_client.type.options_position import OptionsPosition
 from snaptrade_client.type.position import Position
 from snaptrade_client.type.snap_trade_holdings_account_account_id import SnapTradeHoldingsAccountAccountId
 from snaptrade_client.type.snap_trade_holdings_total_value import SnapTradeHoldingsTotalValue
@@ -27,11 +28,13 @@ class RequiredAccountHoldingsAccount(TypedDict):
 class OptionalAccountHoldingsAccount(TypedDict, total=False):
     account: SnapTradeHoldingsAccountAccountId
 
-    balances: typing.List[Balance]
+    balances: typing.Optional[typing.List[Balance]]
 
-    positions: typing.List[Position]
+    positions: typing.Optional[typing.List[Position]]
 
-    orders: typing.List[AccountOrderRecord]
+    option_positions: typing.Optional[typing.List[OptionsPosition]]
+
+    orders: typing.Optional[typing.List[AccountOrderRecord]]
 
     total_value: SnapTradeHoldingsTotalValue
 
