@@ -13,7 +13,7 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.currency import Currency
 
@@ -25,5 +25,7 @@ class OptionalBalance(TypedDict, total=False):
 
     cash: typing.Optional[typing.Union[int, float]]
 
+    buying_power: typing.Optional[typing.Union[int, float]]
+
 class Balance(RequiredBalance, OptionalBalance):
     pass
