@@ -13,8 +13,9 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
+from snaptrade_client.type.brokerage_exchanges import BrokerageExchanges
 from snaptrade_client.type.brokerage_type import BrokerageType
 
 class RequiredBrokerage(TypedDict):
@@ -31,6 +32,10 @@ class OptionalBrokerage(TypedDict, total=False):
 
     aws_s3_logo_url: str
 
+    aws_s3_square_logo_url: typing.Optional[str]
+
+    open_url: typing.Optional[str]
+
     slug: str
 
     url: str
@@ -55,8 +60,7 @@ class OptionalBrokerage(TypedDict, total=False):
 
     brokerage_type: BrokerageType
 
-    # List of exchange ID supported by brokerage
-    exchanges: typing.List[typing.Union[bool, date, datetime, dict, float, int, list, str, None]]
+    exchanges: BrokerageExchanges
 
 class Brokerage(RequiredBrokerage, OptionalBrokerage):
     pass
