@@ -13,7 +13,7 @@
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 
 class RequiredSnapTradeLoginUserRequestBody(TypedDict):
@@ -29,11 +29,14 @@ class OptionalSnapTradeLoginUserRequestBody(TypedDict, total=False):
     # URL to redirect the user to after the user connects their brokerage account
     customRedirect: str
 
-    # The UUID of the brokerage connection to be reconnected
+    # The UUID of the brokerage connection to be reconnected. This parameter should be left empty unless you are reconnecting a disabled connection. See ‘Reconnecting Accounts’ for more information.
     reconnect: str
 
     # Sets whether the connection should be read or trade
     connectionType: str
 
+    # Sets the version of the connection portal to render, with a default to 'v2'
+    connectionPortalVersion: str
+
 class SnapTradeLoginUserRequestBody(RequiredSnapTradeLoginUserRequestBody, OptionalSnapTradeLoginUserRequestBody):
     pass
